% ============================================================================
% InitSimParams
% Author: Brent Dingle, Ph.D.
% Creation Date: 2020
%
% ============================================================================
function sim = InitSimParams()
  sim.t        = 0.0;    % seconds
  sim.dt       = 0.01;
  sim.grav     = 9.81;   % m/s^2
  
  % burntime and thrust are set here in simulation parameters
  % rather than in rocket, as we assume the 'pilot' would be able
  % to set these prior to take-off for any rocket
  % So they are more of a user option than a default constrained by the rocket
  % i.e. prefer to change a sim setting and run 10 different types of rockets
  %      rather than change 10 different rocket settings
  % We may move them to LandingController structure later
  % See also GetThrust function
%  sim.burnTime = 150;       % seconds, time for take-off burn, assume sufficient fuel
%  sim.takeoffThrust = 34e6; % this is used more as Average Thrust 

  sim.burnTime = 1.5;       % seconds, time for take-off burn, assume sufficient fuel
  sim.takeoffThrust = 75;   % this is used more as Average Thrust 
  sim.landingThrust = 75;

  
endfunction
